@@ -47,5 +47,5 @@ def load_binance():
     file_pro.load(total=60)
 
 
-load_binance()
+# load_binance()
 load_okex()
