@@ -55,12 +55,10 @@ class LoadDataKline:
     def load(self, symbol, unix_start, unix_end, csv_writer, timeframe='1m', limit=100, *args, **kwargs):
         unix_delta = limit * self.exchange.parse_timeframe(timeframe) * 1000
         unix_temp = unix_start
-        pbar = tqdm(range(unix_end, unix_start, -unix_delta), desc=symbol)
-        for _ in pbar:
+        for _ in range(unix_end, unix_start, -unix_delta):
             status, result = self._load(symbol, unix_temp - unix_delta, csv_writer, timeframe=timeframe, limit=limit)
             if status is False:
                 break
-            pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
             unix_temp = result[0][0]
 
 
